﻿using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Windows;
using System.Windows.Media;
using Syncfusion.ProjIO;
using Microsoft.Office.Interop.Access.Dao;
using System.Data.OleDb;
using System.IO;
using System.Data.SqlClient;
using System.Text;
using System.Data.Common;
using System.Data;
namespace EssentialProjIOSamples
{
    /// <summary>
    /// Interaction logic for CreateEmptyTask.xaml
    /// </summary>
    public partial class CreateProject : Window
    {
        #region Constants
        private const string DEFAULTIMAGEPATH = @"/../../Data/";
        private string CurrentDirectory = string.Empty;
        #endregion

        # region Constructor
        /// <summary>
        /// Window constructor
        /// </summary>
        public CreateProject()
        {
            InitializeComponent();
            CurrentDirectory = Environment.CurrentDirectory;
            ImageSourceConverter img = new ImageSourceConverter();
            string headerImage = @"../../Data/ProjIOHeader.png";
            this.image1.Source = (ImageSource)img.ConvertFromString(headerImage);
            string icon = @"../../Data/ProjIOIcon.ico";
            this.Icon = (ImageSource)img.ConvertFromString(icon);
        }
        # endregion

        # region Events
        /// <summary>
        /// Creates Project
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnCreate_Click(object sender, RoutedEventArgs e)
        {
            // Create an instance of Project
            Project project = new Project();

            //Esatablishing connection
            System.Data.OleDb.OleDbConnection conn = new System.Data.OleDb.OleDbConnection();
            conn.ConnectionString = @"Provider=Microsoft.ACE.OLEDB.12.0;" +
                @"Data source= ..\..\Data\Database1.accdb;";
            //Opens connection
            conn.Open();
            OleDbCommand command = new OleDbCommand("select * from Table1", conn);
            command.ExecuteNonQuery();
            //Reads the data
            OleDbDataReader reader = command.ExecuteReader();
            string text = null;            
            while (reader.Read())
            {
                //Gets the data from first Field
                text = reader.GetValue(0).ToString();
            }
            //Loads the retrieved data into stream
            MemoryStream stream = new MemoryStream();
            StreamWriter writer = new StreamWriter(stream);
            writer.Write(text);
            writer.Flush();
            stream.Position = 0;
            //Opens stream
            project = ProjectReader.Open(stream);
            //Saves teh project file
            project.Save("result.xml");
        }   
        # endregion

        #region HelperMethods
        /// <summary>
        /// Get the input file and return the path of input file
        /// </summary>
        /// <param name="inputFile"></param>
        /// <returns></returns>

        private string GetFullPath(string imageFile)
        {
            return string.Format(DEFAULTIMAGEPATH, imageFile);
        }
        
        #endregion
        

        private void btnCreate2_Click(object sender, RoutedEventArgs e)
        {
            // Create an instance of Project
            Project project = new Project();
            
            //creating a new tasks
            Task scopeTask = CreateTask("Scope", new DateTime(2011, 12, 5), new DateTime(2011, 12, 19));// TimeSpan.FromHours(80));5
            scopeTask.Duration = new TimeSpan(80, 0, 0);
            //scopeTask.IsSummary = true;
            Task detProjectScopeTask = CreateTask("Determine project scope", new DateTime(2011, 12, 5), new DateTime(2011, 12, 7));// TimeSpan.FromHours(16));
            Task secureProjectScopeTask = CreateTask("Secure Project sponsorship", new DateTime(2011, 12, 8), new DateTime(2011, 12, 9)); //TimeSpan.FromHours(16));
            Task defPreliminaryTask = CreateTask("Define preliminary resources", new DateTime(2011, 12, 10), new DateTime(2011, 12, 13)); //TimeSpan.FromHours(16));
            Task secureCoreResourcesTask = CreateTask("Secure core resources", new DateTime(2011, 12, 14), new DateTime(2011, 12, 15)); //TimeSpan.FromHours(16));
            Task secureCompleteTask = CreateTask("Secure Complete", new DateTime(2011, 12, 16), new DateTime(2011, 12, 19)); //TimeSpan.FromHours(16));

            //Adding the subtasks into the parent task.
            scopeTask.Children.Add(detProjectScopeTask);
            scopeTask.Children.Add(secureProjectScopeTask);
            scopeTask.Children.Add(defPreliminaryTask);
            scopeTask.Children.Add(secureCoreResourcesTask);
            scopeTask.Children.Add(secureCompleteTask);

            //Add the scope task to the project
            project.RootTask.Children.Add(scopeTask);

            //Invoking this method to recalculate IDs of the task present in the project
            project.CalculateTaskIDs();

            // Create task links
            TaskLink scopeLink = new TaskLink(detProjectScopeTask, secureProjectScopeTask, TaskLinkType.FinishToStart);
            TaskLink sponsorLink = new TaskLink(secureProjectScopeTask, defPreliminaryTask, TaskLinkType.FinishToStart);
            TaskLink preLink = new TaskLink(defPreliminaryTask, secureCoreResourcesTask, TaskLinkType.FinishToStart);
            TaskLink coreLink = new TaskLink(secureCoreResourcesTask, secureCompleteTask, TaskLinkType.FinishToStart);

            // Save the project
            project.Save("Task.xml");

            //Loads the file in stream reader
            StreamReader reader1 = new StreamReader("Task.xml");
            //Reads the file data
            string xmlText = reader1.ReadToEnd();
            //Establishing connection
            System.Data.OleDb.OleDbConnection conn = new System.Data.OleDb.OleDbConnection();
            conn.ConnectionString = @"Provider=Microsoft.ACE.OLEDB.12.0;" +
                @"Data source= ..\..\Data\Database1.accdb;";
            //Opens connection
            conn.Open();
            //Inserts data in database
            OleDbCommand command = new OleDbCommand("INSERT INTO Table1(Data) VALUES ('" + xmlText + "')", conn);
            command.ExecuteNonQuery();
            conn.Close();
        }

        /// <summary>
        /// Create a task with the specified properties
        /// </summary>
        /// <param name="taskName">The name of the task</param>
        /// <param name="startTime">The start time of the task</param>
        /// <param name="duration">The duration for the task</param>
        /// <returns>Returns the created task</returns>
        private Task CreateTask(string taskName, DateTime startTime, DateTime finishTime)
        {
            //creating a new task
            Task task = new Task(taskName);
            //specifying the start date and duration for the task
            task.Start = startTime;
            task.Finish = finishTime;
            task.Duration = new TimeSpan(16, 0, 0);
            return task;
        }

    }
}